#!/usr/bin/lua
require "lunit"
log = require "syslog"
lfs = require "lfs"

module("function-tests", package.seeall, lunit.testcase)

function setup()
	local currentdir = lfs.currentdir()
	package.path = package.path..";"..currentdir.."/share/?.lua;"..currentdir.."/etc/rules/?.lua;"..currentdir.."/etc/rules/custom/?.lua"
	dofile "etc/config.lua"
	require "share/synergy_inc"

end

function test_pack_arguments()
	local should_be_table = pack_arguments("We", "should", "become", "a", "table")
	assert_table(should_be_table, "Expected a table got "..type(should_be_table))
end

function test_is_poller()
	local poller = is_poller()
	assert_false(poller, "Expected this machine not to be a poller, function says it is though")
end

function test_get_rule_list()
	-- No rules exist, created bogus files
	config.tree_dir = "etc/"
	os.execute("touch "..config.tree_dir.."testrule1.lua")
	os.execute("touch "..config.tree_dir.."testrule2.lua")
	local s, list_of_rules, m = pcall(get_rule_list)
	assert_table(list_of_rules, "Expected a list of rules but didn't recieve a table, got "..type(list_of_rules))
	assert_not_equal(0, table.getn(list_of_rules), "Expected a list of rules but recieved an empty table")
	-- Cleanup bogus files
	os.execute("rm -f "..config.tree_dir.."testrule1.lua")
	os.execute("rm -f "..config.tree_dir.."testrule2.lua")
end

function test_get_socket_path()
	config.livestatus_config_path = "test/livestatus_bogus_config.yml"
	local path = get_socket_path()
	-- The path should not be the default
	assert_not_equal(config.default_ls_path, path, "Expected to get livestatus path from file but got: "..tostring(path))
	config.livestatus_config_path = "path/to/something/that/do/not/exist"
	local default_path = get_socket_path()
	-- The path should be the default
	assert_equal(config.default_ls_path, default_path, "Expected to get the default path to livestatus socket but got: "..tostring(default_path))
end

function teardown()

end
